@@ -1,9 +1,9 @@
-'''
+"""
 Date: 2022.02.02 18:14
 Description: Omit
 LastEditors: Rustle Karl
 LastEditTime: 2022.02.02 18:14
-'''
+"""
 import click
 from click_aliases import ClickAliasedGroup
 
@@ -19,12 +19,18 @@ def command_ccf():
 
 
 @command_ccf.command(
-        aliases=['py'],
-        context_settings={'help_option_names': ['-h', '--help']},
-        help="Create or display configuration files about Python."
+    aliases=["py"],
+    context_settings={"help_option_names": ["-h", "--help"]},
+    help="Create or display configuration files about Python.",
+)
+@click.option("--method", "-m", default=1, type=int, help="1 -> .pypirc")
+@click.option(
+    "--read-only",
+    "-r",
+    default=True,
+    type=bool,
+    help="Read only or create configuration files.",
 )
-@click.option('--method', '-m', default=1, type=int, help="1 -> .pypirc")
-@click.option('--read-only', '-r', default=True, type=bool, help="Read only or create configuration files.")
 def python(method, read_only):
     _python(method, read_only)
 
@@ -40,9 +46,12 @@ def clash():
 
 
 @command_ccf.command(
-        aliases=['nn'],
-        help="Create a new article for hugo."
+    aliases=["nn"],
+    context_settings={"help_option_names": ["-h", "--help"]},
+    help="Create a new article for hugo.",
+)
+@click.option(
+    "--path", "-p", required=True, type=str, help="The file path for a new article."
 )
-@click.option('--path', '-p', required=True, type=str, help="The file path for a new article.")
 def notes(path):
     _new_article(path)
