@@ -1,19 +1,19 @@
-'''
+"""
 Date: 2022.02.03 9:17
 Description: Omit
 LastEditors: Rustle Karl
 LastEditTime: 2022.02.03 9:17
-'''
+"""
 import os
 import sys
 
 import click
 
 
-def writer(conf, content='', read_only=True, official=''):
-    if not read_only and content != '':
+def writer(conf, content="", read_only=True, official=""):
+    if not read_only and content != "":
         os.makedirs(os.path.dirname(conf), exist_ok=True)
-        with open(conf, 'w', encoding='utf8', newline='\n') as fp:
+        with open(conf, "w", encoding="utf8", newline="\n") as fp:
             fp.write(content)
 
     if official:
@@ -23,8 +23,8 @@ def writer(conf, content='', read_only=True, official=''):
 
 
 def is_windows():
-    return sys.platform.startswith('win')
+    return sys.platform.startswith("win")
 
 
 def join_user(path):
-    return os.path.join(os.path.expanduser('~'), path)
+    return os.path.join(os.path.expanduser("~"), path)
