@@ -1,9 +1,9 @@
-'''
+"""
 Date: 2022.02.02 19:56
 Description: Omit
 LastEditors: Rustle Karl
 LastEditTime: 2022.02.02 19:56
-'''
+"""
 import base64
 import json
 
@@ -21,22 +21,22 @@ def upload(path) -> UploadResult:
     result = UploadResult()
 
     response = session.post(
-            'https://imio.jd.com/uploadfile/file/post.do',
-            {
-                'appId': 'im.customer',
-                'clientType': 'comet',
-                's': base64.b64encode(open(path, 'rb').read()),
-            }
+        "https://imio.jd.com/uploadfile/file/post.do",
+        {
+            "appId": "im.customer",
+            "clientType": "comet",
+            "s": base64.b64encode(open(path, "rb").read()),
+        },
     )
 
     if response.status_code == 200:
         html: lxml.html.HtmlElement = lxml.html.fromstring(response.content)
-        body = json.loads(html.find('body').text)
+        body = json.loads(html.find("body").text)
 
-        if body['code'] == 0:
+        if body["code"] == 0:
             result.success = True
-            result.remote_url = body['path']
+            result.remote_url = body["path"]
 
-        result.message = body['desc']
+        result.message = body["desc"]
 
     return result
